import { defineStore } from 'pinia'
import { reactive } from 'vue'
import { setToken, deleteToken } from '@/utils/auth'
import { smsLogin, passwordLogin } from '@/api/common/index'
import { logout } from '@/api/common/index'
import { getUserInfo } from '@/api/personal/user'

export const userLocaleStore = defineStore('user',
  () => {
    let accountInfo = reactive({}) // 登录返回的信息
    let userInfo = reactive({}) // 当前登录账号信息

    // 短信登录
    const handleSmsLogin = async (data) => {
      return new Promise((resolve, reject) => {
        smsLogin(data).then(res => {
          const { data } = res
          console.log(data, 'res-login')
          setToken(data.accessToken)
          accountInfo = data
          localStorage.setItem('accountInfo', JSON.stringify(data))
          localStorage.setItem('expiresTime', data.expiresTime) // token过期时间
          getUserInfos()
          resolve()
        }).catch(err => { reject(err) })
      })
    }

    // 密码登录
    const handlePasswordLogin = async (data) => {
      return new Promise((resolve, reject) => {
        passwordLogin(data).then(res => {
          const { data } = res
          console.log(data, 'res-login-password')
          setToken(data.accessToken)
          accountInfo = data
          localStorage.setItem('accountInfo', JSON.stringify(data))
          localStorage.setItem('expiresTime', data.expiresTime) // token过期时间
          getUserInfos()
          resolve()
        }).catch(err => { reject(err) })
      })
    }

    // 获取当前登录账户信息
    const getUserInfos = async () => {
      try {
        const { data } = await getUserInfo({ id: accountInfo.userId })
        userInfo = data
        localStorage.setItem('userInfo', JSON.stringify(data))
      } catch (error) {
        console.log(error, 'get-user-info')
        alert(error.msg)
      }
    }

    // 退出登录
    const userLogout = async () => {
      await logout()
      deleteToken()
      userInfo = {}
      accountInfo = {}
      localStorage.clear()
    }
    return {
      userInfo,
      handleSmsLogin,
      userLogout,
      handlePasswordLogin
    }
  },
  {
    persist: true,
  }
)

